@@ -2,7 +2,8 @@ from __future__ import annotations
 
 import logging
 import os
-from typing import TYPE_CHECKING, Callable, Literal
+from collections.abc import Callable
+from typing import TYPE_CHECKING, Literal
 
 import numpy as np
 from tqdm import tqdm
@@ -32,23 +33,7 @@ DatasetNameType = Literal[
     "touche2020",
 ]
 
-dataset_name_to_id = {
-    "climatefever": "sentence-transformers/NanoClimateFEVER-bm25",
-    "dbpedia": "sentence-transformers/NanoDBPedia-bm25",
-    "fever": "sentence-transformers/NanoFEVER-bm25",
-    "fiqa2018": "sentence-transformers/NanoFiQA2018-bm25",
-    "hotpotqa": "sentence-transformers/NanoHotpotQA-bm25",
-    "msmarco": "sentence-transformers/NanoMSMARCO-bm25",
-    "nfcorpus": "sentence-transformers/NanoNFCorpus-bm25",
-    "nq": "sentence-transformers/NanoNQ-bm25",
-    "quoraretrieval": "sentence-transformers/NanoQuoraRetrieval-bm25",
-    "scidocs": "sentence-transformers/NanoSCIDOCS-bm25",
-    "arguana": "sentence-transformers/NanoArguAna-bm25",
-    "scifact": "sentence-transformers/NanoSciFact-bm25",
-    "touche2020": "sentence-transformers/NanoTouche2020-bm25",
-}
-
-dataset_name_to_human_readable = {
+DATASET_NAME_TO_HUMAN_READABLE = {
     "climatefever": "ClimateFEVER",
     "dbpedia": "DBPedia",
     "fever": "FEVER",
@@ -71,8 +56,9 @@ class CrossEncoderNanoBEIREvaluator(SentenceEvaluator):
 
     The collection is a set of datasets based on the BEIR collection, but with a significantly smaller size, so it can
     be used for quickly evaluating the retrieval performance of a model before committing to a full evaluation.
-    The datasets are available on Hugging Face in the `NanoBEIR with BM25 collection <https://huggingface.co/collections/sentence-transformers/nanobeir-with-bm25-rankings-67bdcbc629f007c15bf358d8>`_.
-    This evaluator will return the same metrics as the CrossEncoderRerankingEvaluator (i.e., MRR@k, nDCG@k, MAP), for each dataset and on average.
+    The datasets are available on Hugging Face in the `NanoBEIR collection <https://huggingface.co/collections/sentence-transformers/nanobeir-datasets>`_.
+    This evaluator will return the same metrics as the :class:`~sentence_transformers.cross_encoder.evaluation.CrossEncoderRerankingEvaluator`
+    (i.e., MRR@k, nDCG@k, MAP), for each dataset and on average.
 
     Rather than reranking all documents for each query, the evaluator will only rerank the ``rerank_k`` documents from
     a BM25 ranking. When your logging is set to INFO, the evaluator will print the MAP, MRR@k, and nDCG@k for each dataset
@@ -95,8 +81,23 @@ class CrossEncoderNanoBEIREvaluator(SentenceEvaluator):
         :class:`~sentence_transformers.cross_encoder.training_args.CrossEncoderTrainingArguments` to automatically load the
         best model based on a specific metric of interest.
 
+    .. warning::
+
+        When not specifying the ``dataset_names`` manually, the evaluator will exclude the ``arguana`` and ``touche2020``
+        datasets as their Argument Retrieval task differs meaningfully from the other datasets. This differs from
+        :class:`~sentence_transformers.evaluation.NanoBEIREvaluator` and
+        :class:`~sentence_transformers.sparse_encoder.evaluation.SparseNanoBEIREvaluator`, which include all datasets
+        by default.
+
     Args:
-        dataset_names (List[str]): The names of the datasets to evaluate on. If not specified, use all datasets except arguana and touche2020.
+        dataset_names (List[str]): The short names of the datasets to evaluate on (e.g., "climatefever", "msmarco").
+            If not specified, all predefined NanoBEIR datasets except arguana and touche2020 are used. The full list
+            of available datasets is: "climatefever", "dbpedia", "fever", "fiqa2018", "hotpotqa", "msmarco",
+            "nfcorpus", "nq", "quoraretrieval", "scidocs", "arguana", "scifact", and "touche2020".
+        dataset_id (str): The HuggingFace dataset ID to load the datasets from. Defaults to
+            "sentence-transformers/NanoBEIR-en". The dataset must contain "corpus", "queries", "qrels", and "bm25"
+            subsets for each NanoBEIR dataset, stored under splits named ``Nano{DatasetName}`` (for example,
+            ``NanoMSMARCO`` or ``NanoNFCorpus``).
         rerank_k (int): The number of documents to rerank from the BM25 ranking. Defaults to 100.
         at_k (int, optional): Only consider the top k most similar documents to each query for the evaluation. Defaults to 10.
         always_rerank_positives (bool): If True, always evaluate with all positives included. If False, only include
@@ -109,6 +110,12 @@ class CrossEncoderNanoBEIREvaluator(SentenceEvaluator):
         aggregate_fn (Callable[[list[float]], float]): The function to aggregate the scores. Defaults to np.mean.
         aggregate_key (str): The key to use for the aggregated score. Defaults to "mean".
 
+    .. tip::
+
+        See this `NanoBEIR datasets collection on Hugging Face <https://huggingface.co/collections/sentence-transformers/nanobeir-datasets>`_
+        with valid NanoBEIR ``dataset_id`` options for different languages. The datasets must contain a "bm25" subset
+        with BM25 rankings for the reranking evaluation to work.
+
     Example:
         ::
 
@@ -160,11 +167,35 @@ class CrossEncoderNanoBEIREvaluator(SentenceEvaluator):
             # NanoBEIR_R100_mean_ndcg@10
             print(results[evaluator.primary_metric])
             # 0.60716840988382
+
+        Evaluating on custom/translated datasets::
+
+            import logging
+            from pprint import pprint
+
+            from sentence_transformers.cross_encoder import CrossEncoder
+            from sentence_transformers.cross_encoder.evaluation import CrossEncoderNanoBEIREvaluator
+
+            logging.basicConfig(level=logging.INFO, format="%(asctime)s - %(message)s")
+
+            # Load a model
+            model = CrossEncoder("cross-encoder/mmarco-mMiniLMv2-L12-H384-v1")
+
+            # Load & run the evaluator
+            evaluator = CrossEncoderNanoBEIREvaluator(
+                ["msmarco", "nq"],
+                dataset_id="Serbian-AI-Society/NanoBEIR-sr",
+                batch_size=16,
+            )
+            results = evaluator(model)
+            print(results[evaluator.primary_metric])
+            pprint({key: value for key, value in results.items() if "ndcg@10" in key})
     """
 
     def __init__(
         self,
-        dataset_names: list[DatasetNameType] | None = None,
+        dataset_names: list[DatasetNameType | str] | None = None,
+        dataset_id: str = "sentence-transformers/NanoBEIR-en",
         rerank_k: int = 100,
         at_k: int = 10,
         always_rerank_positives: bool = True,
@@ -177,8 +208,9 @@ class CrossEncoderNanoBEIREvaluator(SentenceEvaluator):
         super().__init__()
         if dataset_names is None:
             # We exclude arguana and touche2020 because their Argument Retrieval meaningfully task differs from the others
-            dataset_names = [key for key in dataset_name_to_id if key not in ["arguana", "touche2020"]]
+            dataset_names = [key for key in DATASET_NAME_TO_HUMAN_READABLE if key not in ["arguana", "touche2020"]]
         self.dataset_names = dataset_names
+        self.dataset_id = dataset_id
         self.rerank_k = rerank_k
         self.at_k = at_k
         self.always_rerank_positives = always_rerank_positives
@@ -287,37 +319,59 @@ class CrossEncoderNanoBEIREvaluator(SentenceEvaluator):
 
         return per_dataset_results
 
-    def _get_human_readable_name(self, dataset_name: DatasetNameType) -> str:
-        human_readable_name = f"Nano{dataset_name_to_human_readable[dataset_name.lower()]}_R{self.rerank_k}"
-        return human_readable_name
+    def _get_human_readable_name(self, dataset_name: DatasetNameType | str) -> str:
+        return f"Nano{DATASET_NAME_TO_HUMAN_READABLE[dataset_name.lower()]}_R{self.rerank_k}"
 
-    def _load_dataset(self, dataset_name: DatasetNameType, **ir_evaluator_kwargs) -> CrossEncoderRerankingEvaluator:
-        if not is_datasets_available():
-            raise ValueError(
-                "datasets is not available. Please install it to use the CrossEncoderNanoBEIREvaluator via `pip install datasets`."
-            )
-        from datasets import load_dataset
+    def _load_dataset(
+        self, dataset_name: DatasetNameType | str, **ir_evaluator_kwargs
+    ) -> CrossEncoderRerankingEvaluator:
+        if dataset_name.lower() not in DATASET_NAME_TO_HUMAN_READABLE:
+            raise ValueError(f"Dataset '{dataset_name}' is not a valid NanoBEIR dataset.")
+        human_readable = DATASET_NAME_TO_HUMAN_READABLE[dataset_name.lower()]
+        split_name = f"Nano{human_readable}"
+
+        corpus = self._load_dataset_subset_split("corpus", split=split_name, required_columns=["_id", "text"])
+        queries = self._load_dataset_subset_split("queries", split=split_name, required_columns=["_id", "text"])
+        qrels = self._load_dataset_subset_split("qrels", split=split_name, required_columns=["query-id", "corpus-id"])
+        bm25 = self._load_dataset_subset_split("bm25", split=split_name, required_columns=["query-id", "corpus-ids"])
 
-        dataset_path = dataset_name_to_id[dataset_name.lower()]
-        corpus = load_dataset(dataset_path, "corpus", split="train")
         corpus_mapping = dict(zip(corpus["_id"], corpus["text"]))
-        queries = load_dataset(dataset_path, "queries", split="train")
         query_mapping = dict(zip(queries["_id"], queries["text"]))
-        relevance = load_dataset(dataset_path, "relevance", split="train")
+        qrels_mapping = {}
+        for sample in qrels:
+            corpus_ids = sample.get("corpus-id")
+            if sample["query-id"] not in qrels_mapping:
+                qrels_mapping[sample["query-id"]] = set()
 
-        def mapper(sample, corpus_mapping: dict[str, str], query_mapping: dict[str, str], rerank_k: int):
+            if isinstance(corpus_ids, list):
+                qrels_mapping[sample["query-id"]].update(corpus_ids)
+            else:
+                qrels_mapping[sample["query-id"]].add(corpus_ids)
+
+        def mapper(
+            sample,
+            corpus_mapping: dict[str, str],
+            query_mapping: dict[str, str],
+            qrels_mapping: dict[str, set[str]],
+            rerank_k: int,
+        ):
             query = query_mapping[sample["query-id"]]
-            positives = [corpus_mapping[positive_id] for positive_id in sample["positive-corpus-ids"]]
-            documents = [corpus_mapping[document_id] for document_id in sample["bm25-ranked-ids"][:rerank_k]]
+            positives = [corpus_mapping[positive_id] for positive_id in qrels_mapping[sample["query-id"]]]
+            documents = [corpus_mapping[document_id] for document_id in sample["corpus-ids"][:rerank_k]]
             return {
                 "query": query,
                 "positive": positives,
                 "documents": documents,
             }
 
-        relevance = relevance.map(
+        relevance = bm25.map(
             mapper,
-            fn_kwargs={"corpus_mapping": corpus_mapping, "query_mapping": query_mapping, "rerank_k": self.rerank_k},
+            fn_kwargs={
+                "corpus_mapping": corpus_mapping,
+                "query_mapping": query_mapping,
+                "qrels_mapping": qrels_mapping,
+                "rerank_k": self.rerank_k,
+            },
         )
 
         human_readable_name = self._get_human_readable_name(dataset_name)
@@ -327,20 +381,44 @@ class CrossEncoderNanoBEIREvaluator(SentenceEvaluator):
             **ir_evaluator_kwargs,
         )
 
+    def _load_dataset_subset_split(self, subset: str, split: str, required_columns: list[str]):
+        if not is_datasets_available():
+            raise ValueError(
+                "datasets is not available. Please install it to use the CrossEncoderNanoBEIREvaluator via `pip install datasets`."
+            )
+        from datasets import load_dataset
+
+        try:
+            dataset = load_dataset(self.dataset_id, subset, split=split)
+        except Exception as e:
+            raise ValueError(
+                f"Could not load subset '{subset}' split '{split}' from dataset '{self.dataset_id}'."
+            ) from e
+
+        if missing_columns := set(required_columns) - set(dataset.column_names):
+            raise ValueError(
+                f"Subset '{subset}' split '{split}' from dataset '{self.dataset_id}' is missing required columns: {list(missing_columns)}."
+            )
+        return dataset
+
     def _validate_dataset_names(self):
         if len(self.dataset_names) == 0:
             raise ValueError("dataset_names cannot be empty. Use None to evaluate on all datasets.")
-        if missing_datasets := [
-            dataset_name for dataset_name in self.dataset_names if dataset_name.lower() not in dataset_name_to_id
-        ]:
+        missing_datasets = [
+            dataset_name
+            for dataset_name in self.dataset_names
+            if dataset_name.lower() not in DATASET_NAME_TO_HUMAN_READABLE
+        ]
+        if missing_datasets:
             raise ValueError(
-                f"Dataset(s) {missing_datasets} not found in the NanoBEIR collection. "
-                f"Valid dataset names are: {list(dataset_name_to_id.keys())}"
+                f"Dataset(s) {missing_datasets} are not valid NanoBEIR datasets. "
+                f"Valid dataset names are: {list(DATASET_NAME_TO_HUMAN_READABLE.keys())}"
             )
 
     def get_config_dict(self):
         return {
             "dataset_names": self.dataset_names,
+            "dataset_id": self.dataset_id,
             "rerank_k": self.rerank_k,
             "at_k": self.at_k,
             "always_rerank_positives": self.always_rerank_positives,
