@@ -4,7 +4,8 @@ import heapq
 import json
 import logging
 import os
-from typing import TYPE_CHECKING, Callable
+from collections.abc import Callable
+from typing import TYPE_CHECKING
 
 import numpy as np
 import torch
@@ -236,8 +237,9 @@ class InformationRetrievalEvaluator(SentenceEvaluator):
 
         scores = self.compute_metrices(model, output_path=output_path, *args, **kwargs)
 
-        # Write results to disc
+        # Write results to disk
         if output_path is not None and self.write_csv:
+            os.makedirs(output_path, exist_ok=True)
             csv_path = os.path.join(output_path, self.csv_file)
             if not os.path.isfile(csv_path):
                 fOut = open(csv_path, mode="w", encoding="utf-8")
