@@ -2,7 +2,8 @@ from __future__ import annotations
 
 import logging
 import os
-from typing import TYPE_CHECKING, Any, Callable, Literal
+from collections.abc import Callable
+from typing import TYPE_CHECKING, Any, Literal
 
 import numpy as np
 from torch import Tensor
@@ -35,24 +36,7 @@ DatasetNameType = Literal[
     "touche2020",
 ]
 
-
-dataset_name_to_id = {
-    "climatefever": "zeta-alpha-ai/NanoClimateFEVER",
-    "dbpedia": "zeta-alpha-ai/NanoDBPedia",
-    "fever": "zeta-alpha-ai/NanoFEVER",
-    "fiqa2018": "zeta-alpha-ai/NanoFiQA2018",
-    "hotpotqa": "zeta-alpha-ai/NanoHotpotQA",
-    "msmarco": "zeta-alpha-ai/NanoMSMARCO",
-    "nfcorpus": "zeta-alpha-ai/NanoNFCorpus",
-    "nq": "zeta-alpha-ai/NanoNQ",
-    "quoraretrieval": "zeta-alpha-ai/NanoQuoraRetrieval",
-    "scidocs": "zeta-alpha-ai/NanoSCIDOCS",
-    "arguana": "zeta-alpha-ai/NanoArguAna",
-    "scifact": "zeta-alpha-ai/NanoSciFact",
-    "touche2020": "zeta-alpha-ai/NanoTouche2020",
-}
-
-dataset_name_to_human_readable = {
+DATASET_NAME_TO_HUMAN_READABLE = {
     "climatefever": "ClimateFEVER",
     "dbpedia": "DBPedia",
     "fever": "FEVER",
@@ -73,13 +57,24 @@ class NanoBEIREvaluator(SentenceEvaluator):
     """
     This class evaluates the performance of a SentenceTransformer Model on the NanoBEIR collection of Information Retrieval datasets.
 
-    The collection is a set of datasets based on the BEIR collection, but with a significantly smaller size, so it can
-    be used for quickly evaluating the retrieval performance of a model before committing to a full evaluation.
-    The datasets are available on Hugging Face in the `NanoBEIR collection <https://huggingface.co/collections/zeta-alpha-ai/nanobeir-66e1a0af21dfd93e620cd9f6>`_.
-    This evaluator will return the same metrics as the InformationRetrievalEvaluator (i.e., MRR, nDCG, Recall@k), for each dataset and on average.
+    The NanoBEIR collection consists of downsized versions of several BEIR information-retrieval datasets, making it
+    suitable for quickly benchmarking a model's retrieval performance before running a full-scale BEIR evaluation.
+    The datasets are available on Hugging Face in the Sentence Transformers `NanoBEIR collection <https://huggingface.co/collections/sentence-transformers/nanobeir-datasets>`_,
+    which reformats the `original collection <https://huggingface.co/collections/zeta-alpha-ai/nanobeir>`_ from Zeta Alpha
+    into the default `NanoBEIR-en <https://huggingface.co/datasets/sentence-transformers/NanoBEIR-en>`_ dataset,
+    alongside many translated versions.
+    This evaluator reports the same metrics as the :class:`~sentence_transformers.evaluation.InformationRetrievalEvaluator`
+    (e.g., MRR, nDCG, Recall@k) for each dataset individually, as well as aggregated across all datasets.
 
     Args:
-        dataset_names (List[str]): The names of the datasets to evaluate on. Defaults to all datasets.
+        dataset_names (List[str]): The short names of the datasets to evaluate on (e.g., "climatefever", "msmarco").
+            If not specified, all predefined NanoBEIR datasets are used. The full list of available datasets is:
+            "climatefever", "dbpedia", "fever", "fiqa2018", "hotpotqa", "msmarco", "nfcorpus", "nq", "quoraretrieval",
+            "scidocs", "arguana", "scifact", and "touche2020".
+        dataset_id (str): The HuggingFace dataset ID to load the datasets from. Defaults to
+            "sentence-transformers/NanoBEIR-en". The dataset must contain "corpus", "queries", and "qrels"
+            subsets for each NanoBEIR dataset, stored under splits named ``Nano{DatasetName}`` (for example,
+            ``NanoMSMARCO`` or ``NanoNFCorpus``).
         mrr_at_k (List[int]): A list of integers representing the values of k for MRR calculation. Defaults to [10].
         ndcg_at_k (List[int]): A list of integers representing the values of k for NDCG calculation. Defaults to [10].
         accuracy_at_k (List[int]): A list of integers representing the values of k for accuracy calculation. Defaults to [1, 3, 5, 10].
@@ -98,6 +93,11 @@ class NanoBEIREvaluator(SentenceEvaluator):
         write_predictions (bool): Whether to write the predictions to a JSONL file. Defaults to False.
             This can be useful for downstream evaluation as it can be used as input to the :class:`~sentence_transformers.sparse_encoder.evaluation.ReciprocalRankFusionEvaluator` that accept precomputed predictions.
 
+    .. tip::
+
+        See this `NanoBEIR datasets collection on Hugging Face <https://huggingface.co/collections/sentence-transformers/nanobeir-datasets>`_
+        with valid NanoBEIR ``dataset_id`` options for different languages.
+
     Example:
         ::
 
@@ -186,13 +186,34 @@ class NanoBEIREvaluator(SentenceEvaluator):
             # => "NanoBEIR_mean_cosine_ndcg@10"
             print(results[evaluator.primary_metric])
             # => 0.8084508771660436
+
+        Evaluating on custom/translated datasets::
+
+            import logging
+            from pprint import pprint
+
+            from sentence_transformers import SentenceTransformer
+            from sentence_transformers.evaluation import NanoBEIREvaluator
+
+            logging.basicConfig(format="%(asctime)s - %(message)s", datefmt="%Y-%m-%d %H:%M:%S", level=logging.INFO)
+
+            model = SentenceTransformer("google/embeddinggemma-300m")
+            evaluator = NanoBEIREvaluator(
+                ["msmarco", "nq"],
+                dataset_id="lightonai/NanoBEIR-de",
+                batch_size=32,
+            )
+            results = evaluator(model)
+            print(results[evaluator.primary_metric])
+            pprint({key: value for key, value in results.items() if "ndcg@10" in key})
     """
 
     information_retrieval_class = InformationRetrievalEvaluator
 
     def __init__(
         self,
-        dataset_names: list[DatasetNameType] | None = None,
+        dataset_names: list[DatasetNameType | str] | None = None,
+        dataset_id: str = "sentence-transformers/NanoBEIR-en",
         mrr_at_k: list[int] = [10],
         ndcg_at_k: list[int] = [10],
         accuracy_at_k: list[int] = [1, 3, 5, 10],
@@ -212,8 +233,9 @@ class NanoBEIREvaluator(SentenceEvaluator):
     ):
         super().__init__()
         if dataset_names is None:
-            dataset_names = list(dataset_name_to_id.keys())
+            dataset_names = list(DATASET_NAME_TO_HUMAN_READABLE.keys())
         self.dataset_names = dataset_names
+        self.dataset_id = dataset_id
         self.aggregate_fn = aggregate_fn
         self.aggregate_key = aggregate_key
         self.write_csv = write_csv
@@ -324,6 +346,7 @@ class NanoBEIREvaluator(SentenceEvaluator):
             agg_results[metric] = self.aggregate_fn(per_metric_results[metric])
 
         if output_path is not None and self.write_csv:
+            os.makedirs(output_path, exist_ok=True)
             csv_path = os.path.join(output_path, self.csv_file)
             if not os.path.isfile(csv_path):
                 fOut = open(csv_path, mode="w", encoding="utf-8")
@@ -395,30 +418,38 @@ class NanoBEIREvaluator(SentenceEvaluator):
 
         return per_dataset_results
 
-    def _get_human_readable_name(self, dataset_name: DatasetNameType) -> str:
-        human_readable_name = f"Nano{dataset_name_to_human_readable[dataset_name.lower()]}"
+    def _get_human_readable_name(self, dataset_name: DatasetNameType | str) -> str:
+        human_readable_name = f"Nano{DATASET_NAME_TO_HUMAN_READABLE[dataset_name.lower()]}"
+
         if self.truncate_dim is not None:
             human_readable_name += f"_{self.truncate_dim}"
         return human_readable_name
 
-    def _load_dataset(self, dataset_name: DatasetNameType, **ir_evaluator_kwargs) -> InformationRetrievalEvaluator:
-        if not is_datasets_available():
-            raise ValueError(
-                "datasets is not available. Please install it to use the NanoBEIREvaluator via `pip install datasets`."
-            )
-        from datasets import load_dataset
+    def _load_dataset(
+        self, dataset_name: DatasetNameType | str, **ir_evaluator_kwargs
+    ) -> InformationRetrievalEvaluator:
+        if dataset_name.lower() not in DATASET_NAME_TO_HUMAN_READABLE:
+            raise ValueError(f"Dataset '{dataset_name}' is not a valid NanoBEIR dataset.")
+        human_readable = DATASET_NAME_TO_HUMAN_READABLE[dataset_name.lower()]
+        split_name = f"Nano{human_readable}"
+
+        corpus = self._load_dataset_subset_split("corpus", split=split_name, required_columns=["_id", "text"])
+        queries = self._load_dataset_subset_split("queries", split=split_name, required_columns=["_id", "text"])
+        qrels = self._load_dataset_subset_split("qrels", split=split_name, required_columns=["query-id", "corpus-id"])
 
-        dataset_path = dataset_name_to_id[dataset_name.lower()]
-        corpus = load_dataset(dataset_path, "corpus", split="train")
-        queries = load_dataset(dataset_path, "queries", split="train")
-        qrels = load_dataset(dataset_path, "qrels", split="train")
         corpus_dict = {sample["_id"]: sample["text"] for sample in corpus if len(sample["text"]) > 0}
         queries_dict = {sample["_id"]: sample["text"] for sample in queries if len(sample["text"]) > 0}
+
         qrels_dict = {}
         for sample in qrels:
+            corpus_ids = sample.get("corpus-id")
             if sample["query-id"] not in qrels_dict:
                 qrels_dict[sample["query-id"]] = set()
-            qrels_dict[sample["query-id"]].add(sample["corpus-id"])
+
+            if isinstance(corpus_ids, list):
+                qrels_dict[sample["query-id"]].update(corpus_ids)
+            else:
+                qrels_dict[sample["query-id"]].add(corpus_ids)
 
         if self.query_prompts is not None:
             ir_evaluator_kwargs["query_prompt"] = self.query_prompts.get(dataset_name, None)
@@ -433,15 +464,38 @@ class NanoBEIREvaluator(SentenceEvaluator):
             **ir_evaluator_kwargs,
         )
 
+    def _load_dataset_subset_split(self, subset: str, split: str, required_columns: list[str]):
+        if not is_datasets_available():
+            raise ValueError(
+                "datasets is not available. Please install it to use the NanoBEIREvaluator via `pip install datasets`."
+            )
+        from datasets import load_dataset
+
+        try:
+            dataset = load_dataset(self.dataset_id, subset, split=split)
+        except Exception as e:
+            raise ValueError(
+                f"Could not load subset '{subset}' split '{split}' from dataset '{self.dataset_id}'."
+            ) from e
+
+        if missing_columns := set(required_columns) - set(dataset.column_names):
+            raise ValueError(
+                f"Subset '{subset}' split '{split}' from dataset '{self.dataset_id}' is missing required columns: {list(missing_columns)}."
+            )
+        return dataset
+
     def _validate_dataset_names(self):
         if len(self.dataset_names) == 0:
             raise ValueError("dataset_names cannot be empty. Use None to evaluate on all datasets.")
-        if missing_datasets := [
-            dataset_name for dataset_name in self.dataset_names if dataset_name.lower() not in dataset_name_to_id
-        ]:
+        missing_datasets = [
+            dataset_name
+            for dataset_name in self.dataset_names
+            if dataset_name.lower() not in DATASET_NAME_TO_HUMAN_READABLE
+        ]
+        if missing_datasets:
             raise ValueError(
-                f"Dataset(s) {missing_datasets} not found in the NanoBEIR collection. "
-                f"Valid dataset names are: {list(dataset_name_to_id.keys())}"
+                f"Dataset(s) {missing_datasets} are not valid NanoBEIR datasets. "
+                f"Valid dataset names are: {list(DATASET_NAME_TO_HUMAN_READABLE.keys())}"
             )
 
     def _validate_prompts(self):
@@ -473,7 +527,7 @@ class NanoBEIREvaluator(SentenceEvaluator):
             super().store_metrics_in_model_card_data(*args, **kwargs)
 
     def get_config_dict(self) -> dict[str, Any]:
-        config_dict = {"dataset_names": self.dataset_names}
+        config_dict = {"dataset_names": self.dataset_names, "dataset_id": self.dataset_id}
         config_dict_candidate_keys = ["truncate_dim", "query_prompts", "corpus_prompts"]
         for key in config_dict_candidate_keys:
             if getattr(self, key) is not None:
