@@ -34,7 +34,7 @@ class DenoisingAutoEncoderLoss(nn.Module):
             tie_encoder_decoder (bool): Whether to tie the trainable parameters of encoder and decoder. Defaults to True.
 
         References:
-            * TSDAE paper: https://arxiv.org/pdf/2104.06979.pdf
+            * TSDAE paper: https://huggingface.co/papers/2104.06979
             * `Unsupervised Learning > TSDAE <../../../examples/sentence_transformer/unsupervised_learning/TSDAE/README.html>`_
 
         Requirements:
@@ -85,9 +85,9 @@ class DenoisingAutoEncoderLoss(nn.Module):
 
         encoder_name_or_path = model.transformers_model.config._name_or_path
         if decoder_name_or_path is None:
-            assert (
-                tie_encoder_decoder
-            ), "Must indicate the decoder_name_or_path argument when tie_encoder_decoder=False!"
+            assert tie_encoder_decoder, (
+                "Must indicate the decoder_name_or_path argument when tie_encoder_decoder=False!"
+            )
         if tie_encoder_decoder:
             if decoder_name_or_path:
                 logger.warning("When tie_encoder_decoder=True, the decoder_name_or_path will be invalid.")
